==> apache-inlong-1.4.0-src.tar.gz: apache-inlong-1.4.0/inlong-manager/manager-dao/src/main/java/org/apache/inlong/manager/dao/mapper/ComponentHeartbeatEntityMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.dao.mapper;

import org.apache.ibatis.annotations.Param;
import org.apache.inlong.manager.dao.entity.ComponentHeartbeatEntity;
import org.apache.inlong.manager.pojo.heartbeat.HeartbeatPageRequest;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface ComponentHeartbeatEntityMapper {

    int insert(ComponentHeartbeatEntity record);

    int insertOrUpdateByKey(ComponentHeartbeatEntity record);

    ComponentHeartbeatEntity selectByPrimaryKey(Integer id);

    ComponentHeartbeatEntity selectByKey(@Param("component") String component, @Param("instance") String instance);

    List<ComponentHeartbeatEntity> selectByCondition(@Param("request") HeartbeatPageRequest request);

    int deleteByPrimaryKey(Integer id);

}

==> apache-inlong-2.3.0-src.tar.gz: apache-inlong-2.3.0/inlong-manager/manager-dao/src/main/java/org/apache/inlong/manager/dao/mapper/ComponentHeartbeatEntityMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.dao.mapper;

import org.apache.inlong.manager.dao.entity.ComponentHeartbeatEntity;
import org.apache.inlong.manager.pojo.heartbeat.HeartbeatPageRequest;

import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface ComponentHeartbeatEntityMapper {

    int insert(ComponentHeartbeatEntity record);

    int insertOrUpdateByKey(ComponentHeartbeatEntity record);

    ComponentHeartbeatEntity selectByKey(@Param("component") String component, @Param("instance") String instance);

    List<ComponentHeartbeatEntity> selectByCondition(@Param("request") HeartbeatPageRequest request);

    /**
     * Get the heartbeat by heartbeat interval
     *
     * @param component component type
     * @param instance component address
     * @param beforeSeconds the modified time was beforeSeconds seconds ago
     */
    ComponentHeartbeatEntity selectTimeOutHeartBeat(@Param("component") String component,
            @Param("instance") String instance, @Param("beforeSeconds") Long beforeSeconds);

}
